@@ -418,6 +418,11 @@
         <source>Show thumbnails for images</source>
         <translation type="unfinished">Mostrar miniaturas para imágenes</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Show details for files</source>
+        <translation type="unfinished">Mostrar detalles para archivos</translation>
+    </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Delete items from clipboard on Paste</source>
